pub struct ParallelStrategy {
pub name: String,
pub tasks: Vec<String>,
}Expand description
A decomposition strategy that breaks a goal into a set of parallel tasks.
Fields
name: StringThe name of the strategy.
tasks: Vec<String>A list of task names, which will be converted into Perform sub-goals.